==> viperx-1.1.1.tgz: package/store/store.js <==
"use strict";
var Promise = require("bluebird");
var cloneDeep = require("lodash/cloneDeep");
var notifier_1 = require("./../observer/notifier");
var Store = (function () {
    function Store(initialState) {
        this.state = cloneDeep(initialState);
        this.notifier = new notifier_1.StateNotifier();
    }
    Store.prototype.cloneState = function (state) {
        return cloneDeep(state || this.state);
    };
    Store.prototype.updateState = function (state) {
        this.state = this.cloneState(state);
        this.notifier.notify();
    };
    Store.prototype.dispatch = function (action) {
        var state;
        if (action instanceof Function) {
            state = action(this.cloneState());
        }
        else {
            state = action.execute(this.cloneState());
        }
        this.updateState(state);
        return state;
    };
    Store.prototype.dispatchAsync = function (action) {
        var _this = this;
        var promise = new Promise(function (resolve, reject) {
            if (action instanceof Function) {
                action(_this.cloneState(), resolve, reject);
            }
            else {
                action.execute(_this.cloneState(), resolve, reject);
            }
        });
        promise.then(function (state) {
            _this.updateState(state);
        });
        return promise;
    };
    Store.prototype.getState = function () {
        return this.cloneState();
    };
    Store.prototype.subscribe = function (listener) {
        this.notifier.subscribe(listener);
    };
    return Store;
}());
exports.Store = Store;

==> viperx-1.1.2.tgz: package/store/store.js <==
"use strict";
var Promise = require("bluebird");
var cloneDeep = require("lodash/cloneDeep");
var notifier_1 = require("./../observer/notifier");
var Store = (function () {
    function Store(initialState) {
        this.state = cloneDeep(initialState);
        this.notifier = new notifier_1.StateNotifier();
    }
    Store.prototype.cloneState = function (state) {
        return cloneDeep(state || this.state);
    };
    Store.prototype.updateState = function (state) {
        this.state = this.cloneState(state);
        this.notifier.notify();
    };
    Store.prototype.dispatch = function (action) {
        var stateClon = this.cloneState();
        if (action instanceof Function) {
            action(stateClon);
        }
        else {
            action.execute(stateClon);
        }
        this.updateState(stateClon);
        return this.cloneState();
    };
    Store.prototype.dispatchAsync = function (action) {
        var _this = this;
        var promise = new Promise(function (resolve, reject) {
            if (action instanceof Function) {
                action(_this.cloneState(), resolve, reject);
            }
            else {
                action.execute(_this.cloneState(), resolve, reject);
            }
        });
        promise.then(function (state) {
            _this.updateState(state);
        });
        return promise;
    };
    Store.prototype.getState = function () {
        return this.cloneState();
    };
    Store.prototype.subscribe = function (listener) {
        this.notifier.subscribe(listener);
    };
    return Store;
}());
exports.Store = Store;
